Developing extensions
=====================

This Section gives basic guidelines to add extensions to the ``otupy``.
Extensions include: 


.. toctree::
   :maxdepth: 1

   encoding
   transfer
   profiles
   actuators

Extensions may be included in and delivered with ``otupy``, or developed
separately. There is no significant difference between the two methods,
apart from the delivery process; the latter is not covered in this
guide. There is no strict naming conventions for the extension modules,
althought following a common convention facilitate the maintenance of
the code by different developers.

